import logging
from unittest import TestCase, skipIf

from cli_base.cli_tools.constants import GITHUB_ACTION
from cli_base.cli_tools.git_history import update_readme_history


class ReadmeHistoryTestCase(TestCase):
    @skipIf(
        # After a release the history may be "changed" because of version bump.
        # We should not block merge requests because of this.
        GITHUB_ACTION,
        reason='Skip on github actions',
    )
    def test_readme_history(self):
        with self.assertNoLogs(level=logging.WARNING):
            update_readme_history(raise_update_error=True)



from cli_base.cli_tools import code_style
from cli_base.tyro_commands import TyroVerbosityArgType

from ha_services.cli_dev import PACKAGE_ROOT, app


@app.command
def fix_code_style(verbosity: TyroVerbosityArgType, color: bool = True):
    """
    Fix code style of all ha_services source code files via darker
    """
    code_style.fix(package_root=PACKAGE_ROOT, darker_color=color, darker_verbose=verbosity > 0)


@app.command
def check_code_style(verbosity: TyroVerbosityArgType, color: bool = True):
    """
    Check code style by calling darker + flake8
    """
    code_style.check(package_root=PACKAGE_ROOT, darker_color=color, darker_verbose=verbosity > 0)
